==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/ServerFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface ServerFluent<A extends ServerFluent<A>> extends Fluent<A>{


    public A addToHosts(int index,String item);
    public A setToHosts(int index,String item);
    public A addToHosts(String... items);
    public A addAllToHosts(Collection<String> items);
    public A removeFromHosts(String... items);
    public A removeAllFromHosts(Collection<String> items);
    public List<String> getHosts();
    public String getHost(int index);
    public String getFirstHost();
    public String getLastHost();
    public String getMatchingHost(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withHosts(List<String> hosts);
    public A withHosts(String... hosts);
    public Boolean hasHosts();
    
/**
 * This method has been deprecated, please use method buildPort instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.networking.v1alpha3.Port getPort();
    public me.snowdrop.istio.api.networking.v1alpha3.Port buildPort();
    public A withPort(me.snowdrop.istio.api.networking.v1alpha3.Port port);
    public Boolean hasPort();
    public A withNewPort(String name,Integer number,String protocol);
    public ServerFluent.PortNested<A> withNewPort();
    public ServerFluent.PortNested<A> withNewPortLike(me.snowdrop.istio.api.networking.v1alpha3.Port item);
    public ServerFluent.PortNested<A> editPort();
    public ServerFluent.PortNested<A> editOrNewPort();
    public ServerFluent.PortNested<A> editOrNewPortLike(me.snowdrop.istio.api.networking.v1alpha3.Port item);
    
/**
 * This method has been deprecated, please use method buildTls instead.
 * @return The buildable object.
 */
@Deprecated public TLSOptions getTls();
    public TLSOptions buildTls();
    public A withTls(TLSOptions tls);
    public Boolean hasTls();
    public ServerFluent.TlsNested<A> withNewTls();
    public ServerFluent.TlsNested<A> withNewTlsLike(TLSOptions item);
    public ServerFluent.TlsNested<A> editTls();
    public ServerFluent.TlsNested<A> editOrNewTls();
    public ServerFluent.TlsNested<A> editOrNewTlsLike(TLSOptions item);

    public interface PortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PortFluent<ServerFluent.PortNested<N>>{

        
    public N and();    public N endPort();
}
    public interface TlsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TLSOptionsFluent<ServerFluent.TlsNested<N>>{

        
    public N and();    public N endTls();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/ServerFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface ServerFluent<A extends ServerFluent<A>> extends Fluent<A>{


    public String getBind();
    public A withBind(String bind);
    public Boolean hasBind();
    public A withNewBind(String arg1);
    public A withNewBind(StringBuilder arg1);
    public A withNewBind(StringBuffer arg1);
    public String getDefaultEndpoint();
    public A withDefaultEndpoint(String defaultEndpoint);
    public Boolean hasDefaultEndpoint();
    public A withNewDefaultEndpoint(String arg1);
    public A withNewDefaultEndpoint(StringBuilder arg1);
    public A withNewDefaultEndpoint(StringBuffer arg1);
    public A addToHosts(int index,String item);
    public A setToHosts(int index,String item);
    public A addToHosts(String... items);
    public A addAllToHosts(Collection<String> items);
    public A removeFromHosts(String... items);
    public A removeAllFromHosts(Collection<String> items);
    public List<String> getHosts();
    public String getHost(int index);
    public String getFirstHost();
    public String getLastHost();
    public String getMatchingHost(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingHost(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withHosts(List<String> hosts);
    public A withHosts(String... hosts);
    public Boolean hasHosts();
    public A addNewHost(String arg1);
    public A addNewHost(StringBuilder arg1);
    public A addNewHost(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildPort instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.networking.v1alpha3.Port getPort();
    public me.snowdrop.istio.api.networking.v1alpha3.Port buildPort();
    public A withPort(me.snowdrop.istio.api.networking.v1alpha3.Port port);
    public Boolean hasPort();
    public A withNewPort(String name,Integer number,String protocol);
    public ServerFluent.PortNested<A> withNewPort();
    public ServerFluent.PortNested<A> withNewPortLike(me.snowdrop.istio.api.networking.v1alpha3.Port item);
    public ServerFluent.PortNested<A> editPort();
    public ServerFluent.PortNested<A> editOrNewPort();
    public ServerFluent.PortNested<A> editOrNewPortLike(me.snowdrop.istio.api.networking.v1alpha3.Port item);
    
/**
 * This method has been deprecated, please use method buildTls instead.
 * @return The buildable object.
 */
@Deprecated public TLSOptions getTls();
    public TLSOptions buildTls();
    public A withTls(TLSOptions tls);
    public Boolean hasTls();
    public ServerFluent.TlsNested<A> withNewTls();
    public ServerFluent.TlsNested<A> withNewTlsLike(TLSOptions item);
    public ServerFluent.TlsNested<A> editTls();
    public ServerFluent.TlsNested<A> editOrNewTls();
    public ServerFluent.TlsNested<A> editOrNewTlsLike(TLSOptions item);

    public interface PortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PortFluent<ServerFluent.PortNested<N>>{

        
    public N and();    public N endPort();
}
    public interface TlsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TLSOptionsFluent<ServerFluent.TlsNested<N>>{

        
    public N and();    public N endTls();
}


}
